from setuptools import setup

setup(name='gnb_distributions_gr',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Mustafa Khamisi',
      author_email='mustafangure@gmail.com',
      zip_safe=False)
